%define	build_doc	0

Name:		nodejs
Version:	0.10.42
Release:	%mkrel 1
Summary:	Evented Server-Side Javascript
Group:		System/Servers
License:	BSD
URL:		http://nodejs.org
Source0:	http://nodejs.org/dist/v%{version}/node-v%{version}.tar.gz
#
# From FC:
#
# The native module Requires generator remains in the nodejs SRPM, so it knows
# the nodejs and v8 versions.  The remainder has migrated to the
# nodejs-packaging SRPM.
Source7: nodejs_native.attr

# Disable running gyp on bundled deps we don't use
Patch1: nodejs-disable-gyp-deps.patch
#
# End FC
#

BuildRequires:	c-ares-devel
BuildRequires:	zlib-devel
BuildRequires:	openssl-devel >= 1.0.1
Provides:	npm = %{version}-%{release}


#we need ABI virtual provides where SONAMEs aren't enough/not present so deps
#break when binary compatibility is broken
%global nodejs_abi 0.10
Provides: nodejs(abi) = %{nodejs_abi}

#this corresponds to the "engine" requirement in package.json
Provides: nodejs(engine) = %{version}

%description
Node.js is a platform built on Chrome's JavaScript runtime
for easily building fast, scalable network applications.
Node.js uses an event-driven, non-blocking I/O model that
makes it lightweight and efficient, perfect for data-intensive
real-time applications that run across distributed devices.

%if %build_doc
%package	doc
Summary: 	Node.js API documentation
Group:		Documentation

%description	docs
The API documentation for the Node.js JavaScript runtime.
%endif

%prep
%setup -q -n node-v%{version}
%autopatch
sed -e 's!"~2"!"2 || 3"!' -i ./deps/npm/node_modules/read-installed/test/fixtures/package.json
sed -e 's!"2"!"2 || 3"!' -i ./deps/npm/node_modules/cmd-shim/package.json

# Make sure nothing gets included from bundled deps (except v8):
# We only delete the source and header files, because
# the remaining build scripts are still used.
find deps/cares -name "*.c" -exec rm -f {} \;
find deps/cares -name "*.h" -exec rm -f {} \;

find deps/npm -name "*.c" -exec rm -f {} \;
find deps/npm -name "*.h" -exec rm -f {} \;

find deps/zlib -name "*.c" -exec rm -f {} \;
find deps/zlib -name "*.h" -exec rm -f {} \;

find deps/openssl -name "*.c" -exec rm -f {} \;
find deps/openssl -name "*.h" -exec rm -f {} \;

%build
#FIXME: some CFLAGS do not seem to be recognized :/
#FIXME: does not build with --shared-libuv (no package in Mageia)
./configure	--prefix=%{_prefix} \
		--shared-openssl \
		--shared-zlib \
		--shared-cares \
		--openssl-use-sys \
		--without-dtrace
%make

%install
%makeinstall_std
# Remove dtrace file again
rm -rf %{buildroot}/%{_prefix}/lib/dtrace

# ensure Requires are added to every native module that match the Provides from
# the nodejs build in the buildroot
install -Dpm0644 %{SOURCE7} %{buildroot}%{_rpmconfigdir}/fileattrs/nodejs_native.attr
cat << EOF > %{buildroot}%{_rpmconfigdir}/nodejs_native.req
#!/bin/sh
echo 'nodejs(abi) = %nodejs_abi'
echo 'nodejs(v8-abi) = %v8_abi'
EOF
chmod 0755 %{buildroot}%{_rpmconfigdir}/nodejs_native.req

%if %build_doc
# Install documentation
mkdir -p %{buildroot}%{_defaultdocdir}/%{name}/html
cp -pr doc/* %{buildroot}%{_defaultdocdir}/%{name}/html
rm -f %{buildroot}%{_defaultdocdir}/%{name}/html/nodejs.1
cp -p LICENSE %{buildroot}%{_defaultdocdir}/%{name}/
%endif

%files
%doc ChangeLog LICENSE README.md AUTHORS
%{_bindir}/node
%{_bindir}/npm
%{_prefix}/lib/node_modules
%{_mandir}/man1/node.*
%{_includedir}/node
%{_rpmconfigdir}/fileattrs/nodejs_native.attr
%{_rpmconfigdir}/nodejs_native.req

%if %build_doc
%files doc
%{_defaultdocdir}/%{name}
%endif


%changelog
* Mon Feb 15 2016 luigiwalser <luigiwalser> 0.10.42-1.mga5
+ Revision: 961429
- 0.10.42 (fixes CVE-2016-2086 and CVE-2016-2216)
- 0.10.41

* Sun May 03 2015 joequant <joequant> 0.10.38-1.mga5
+ Revision: 821164
- update to 0.10.38 to fix security issues in bug 15405

* Mon Oct 27 2014 luigiwalser <luigiwalser> 0.10.33-1.mga5
+ Revision: 793974
- 0.10.33

* Wed Oct 15 2014 umeabot <umeabot> 0.10.30-6.mga5
+ Revision: 750309
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.10.30-5.mga5
+ Revision: 726006
- add native deps support from FC

* Fri Sep 26 2014 tv <tv> 0.10.30-4.mga5
+ Revision: 725139
- rebuild for bogus file deps

* Wed Sep 17 2014 joequant <joequant> 0.10.30-3.mga5
+ Revision: 693134
- fix deps for nodejs

  + umeabot <umeabot>
    - Mageia 5 Mass Rebuild

* Sat Aug 16 2014 dams <dams> 0.10.30-1.mga5
+ Revision: 664405
- new version 0.10.30

* Wed Jul 23 2014 dams <dams> 0.10.29-1.mga5
+ Revision: 655770
- new version 0.10.29

* Fri May 02 2014 dams <dams> 0.10.28-1.mga5
+ Revision: 619739
- new version 0.10.28

* Mon Feb 24 2014 dams <dams> 0.10.26-1.mga5
+ Revision: 596210
- new version 0.10.26

* Tue Feb 04 2014 dams <dams> 0.10.25-1.mga5
+ Revision: 580750
- new version 0.10.25

* Mon Dec 23 2013 dams <dams> 0.10.24-1.mga4
+ Revision: 560066
- new version 0.10.24

* Wed Nov 20 2013 dams <dams> 0.10.22-1.mga4
+ Revision: 552078
- new version 0.10.22

* Wed Oct 23 2013 dams <dams> 0.10.21-1.mga4
+ Revision: 546474
- new version 0.10.21 (DoS Vulnerability)

* Mon Oct 21 2013 umeabot <umeabot> 0.10.20-2.mga4
+ Revision: 538513
- Mageia 4 Mass Rebuild

* Tue Oct 01 2013 dams <dams> 0.10.20-1.mga4
+ Revision: 489822
- new version 0.10.20
- new version 0.10.20

* Wed Sep 25 2013 dams <dams> 0.10.19-1.mga4
+ Revision: 485929
- new version 0.10.19

* Thu Sep 05 2013 dams <dams> 0.10.18-1.mga4
+ Revision: 475233
- new version 0.10.18

* Mon Aug 26 2013 dams <dams> 0.10.17-1.mga4
+ Revision: 471919
- new version 0.10.17

* Sat Jul 27 2013 dams <dams> 0.10.15-1.mga4
+ Revision: 458753
- new version 0.10.15

* Mon Jul 15 2013 dams <dams> 0.10.13-1.mga4
+ Revision: 454553
- new version 0.10.13

* Wed Jun 19 2013 dams <dams> 0.10.12-1.mga4
+ Revision: 445084
- new version 0.10.12

* Thu Jun 13 2013 dams <dams> 0.10.11-1.mga4
+ Revision: 442902
- new version 0.10.11

* Sat Jun 08 2013 dams <dams> 0.10.10-1.mga4
+ Revision: 440640
- new version 0.10.10

* Fri May 31 2013 dams <dams> 0.10.9-1.mga4
+ Revision: 433721
- new version 0.10.9

* Mon May 27 2013 dams <dams> 0.10.8-1.mga4
+ Revision: 428717
- new version 0.10.8

* Thu May 23 2013 dams <dams> 0.10.7-1.mga4
+ Revision: 425004
- new version 0.10.7

* Thu Apr 11 2013 dams <dams> 0.10.3-2.mga3
+ Revision: 409688
- now use bundled v8 as requested by Luigi12 to avoid using buggy v8 package

* Sat Apr 06 2013 dams <dams> 0.10.3-1.mga3
+ Revision: 408511
- new version 0.10.3

* Tue Apr 02 2013 dams <dams> 0.10.2-1.mga3
+ Revision: 407207
- new version 0.10.2

* Fri Mar 29 2013 dams <dams> 0.10.1-1.mga3
+ Revision: 406472
- disable doc for now
- new stable version 0.10.1
- clean and update BR
- add a 'docs' subpackage
- make sure we are not using bundled deps

* Sat Feb 09 2013 fwang <fwang> 0.9.9-1.mga3
+ Revision: 397647
- use shared cares
- update file list
- new version 0.9.9
- rebuild for new v8

* Sat Feb 09 2013 fwang <fwang> 0.9.0-4.mga3
+ Revision: 397503
- rebuild for new v8

  + umeabot <umeabot>
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Sep 24 2012 fedya <fedya> 0.9.0-2.mga3
+ Revision: 297232
- Provides: npm see #820

* Mon Jul 30 2012 shlomif <shlomif> 0.9.0-1.mga3
+ Revision: 276171
- New version 0.9.0 thanks to fedya.

  + dmorgan <dmorgan>
    - New version 0.8.1

* Wed Jan 11 2012 fwang <fwang> 0.4.12-1.mga2
+ Revision: 195003
- new version 0.4.12

  + misc <misc>
    - new version

  + shikamaru <shikamaru>
    - imported package nodejs

